@@ -97,7 +97,10 @@ class sbol_methods2:
                 else:
                     # no iteration over list as else suggests that the property
                     # can't have multiple values
-                    setattr(self.obj, self.sbol_term_suf, self.cell_val)
+                    try:
+                        setattr(self.obj, self.sbol_term_suf, self.cell_val)
+                    except AttributeError:
+                        raise ValueError(f"Can't set attribute {self.sbol_term_pref}_{self.sbol_term_suf} for sheet:{self.sheet}, col: {self.sht_col}, row:{self.sht_row}. It is likely an issue with plural e.g. not sbol_type but sbol_types")
             else:
                 raise ValueError(f'This SBOL object ({type(self.obj)}) has no attribute {self.sbol_term_suf}. The column definitions sheet SBOL Term needs to be updated. (sheet:{self.sheet}, row:{self.sht_row}, col:{self.sht_col})')
 
@@ -146,6 +149,40 @@ class sbol_methods2:
         # used to set the object display id in converter function
         pass
 
+    def types(self):
+        # overwrites standard #DnaRegion biopax where another type is given
+        if self.cell_val not in self.obj.types[0] and len(self.obj.types) == 1:
+            self.obj.types = self.cell_val
+
+    def moduleModuleDefiniton(self):
+        module_name_pref = self.obj_uri.split("/")[-1]
+        module_name_suf = self.cell_val.split("/")[-1]
+        mod1 = sbol2.Module(f"{module_name_pref}_{module_name_suf}")
+        mod1.definition = self.cell_val
+
+        self.obj.modules.add(mod1)
+
+    def additionalFuncComponent(self):
+        fc_name_pref = self.obj_uri.split("/")[-1]
+        fc_name_suf = self.cell_val.split("/")[-1]
+
+        fc1 = sbol2.FunctionalComponent(f"{fc_name_pref}_{fc_name_suf}")
+        fc1.definition = self.cell_val
+        self.obj.functionalComponents.add(fc1)
+
+    def definedFunComponent(self):
+        if isinstance(self.cell_val, list):
+            # pulling the functional component object
+            # by the name (hence the split) from the obj_cit
+            fcobj = self.obj_dict[self.cell_val[0].split("/")[-1]]['object']
+        else:
+            # pulling the functional component object
+            # by the name (hence the split) from the obj_cit
+            fcobj = self.obj_dict[self.cell_val.split("/")[-1]]['object']
+
+        # print(self.obj, fcobj)
+        self.obj.functionalComponents.add(fcobj.copy())
+
     def subcomponents(self):
         # if type is compdef do one thing, if combdev do another, else error
         if isinstance(self.obj, sbol2.componentdefinition.ComponentDefinition):
